Lenses Data Base

# Info on Lenses Data Base

    1. Title: Database for fitting contact lenses

    2. Sources:
         (a) Cendrowska, J. "PRISM: An algorithm for inducing modular rules",
             International Journal of Man-Machine Studies, 1987, 27, 349-370
         (b) Donor: Benoit Julien (Julien@ce.cmu.edu)
         (c) Date: 1 August 1990

    3. Past Usage:
          1. See above.
          2. Witten, I. H. & MacDonald, B. A. (1988). Using concept
             learning for knowledge acquisition. International Journal of
             Man-Machine Studies, 27, (pp. 349-370).

     Notes:  This database is complete (all possible combinations of
             attribute-value pairs are represented).

             Each instance is complete and correct.

             9 rules cover the training set.

    4. Relevant Information Paragraph:
        The examples are complete and noise free.
        The examples highly simplified the problem. The attributes do not
        fully describe all the factors affecting the decision as to which type,
        if any, to fit.

    5. Number of Instances: 24

    6. Number of Attributes: 4 (all nominal)

    7. Attribute Information:
        -- 3 Classes
         1 : the patient should be fitted with hard contact lenses,
         2 : the patient should be fitted with soft contact lenses,
         1 : the patient should not be fitted with contact lenses.

        1. age of the patient: (1) young, (2) pre-presbyopic, (3) presbyopic
        2. spectacle prescription:  (1) myope, (2) hypermetrope
        3. astigmatic:     (1) no, (2) yes
        4. tear production rate:  (1) reduced, (2) normal

    8. Number of Missing Attribute Values:   0

    9. Class Distribution:
       1. hard contact lenses: 4
       2. soft contact lenses: 5
       3. no contact lenses: 15